<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | GoogleAnalytics Plugin 1.2
// +---------------------------------------------------------------------------+
// | autoinstall.php
// |
// | This file provides helper functions for the automatic plugin install. 
// +---------------------------------------------------------------------------+
// | Copyright (C) 2009-2013 by the following authors:
// |
// | Authors: Hiroron               - hiroron AT hiroron DOT com
// +---------------------------------------------------------------------------+
// | 
// | This program is free software; you can redistribute it and/or
// | modify it under the terms of the GNU General Public License
// | as published by the Free Software Foundation; either version 2
// | of the License, or (at your option) any later version.
// | 
// | This program is distributed in the hope that it will be useful,
// | but WITHOUT ANY WARRANTY; without even the implied warranty of
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// | GNU General Public License for more details.
// | 
// | You should have received a copy of the GNU General Public License
// | along with this program; if not, write to the Free Software Foundation,
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// | 
// +---------------------------------------------------------------------------+

/**
* Autoinstall API functions for the GoogleAnalytics plugin
*
* @package GoogleAnalytics
*/

/**
* Plugin autoinstall function
*
* @param    string  $pi_name    Plugin name
* @return   array               Plugin information
*
*/
function plugin_autoinstall_googleanalytics($pi_name)
{
    $pi_name         = 'googleanalytics';
    $pi_display_name = 'GoogleAnalytics';
    $pi_admin        = $pi_display_name . ' Admin';

    $info = array(
        'pi_name'         => $pi_name,
        'pi_display_name' => $pi_display_name,
        'pi_version'      => '1.2.1',
        'pi_gl_version'   => '1.8.0',
        'pi_homepage'     => 'http://hiroron.com/'
    );

    $groups = array(
        $pi_admin => 'Has full access to ' . $pi_display_name . ' features'
    );

    $features = array(
        $pi_name . '.admin'                       => 'Access to ' . $pi_admin,
        'config.' . $pi_name . '.tab_main'        => 'Access to configure general ' . $pi_name . ' settings',
        'config.' . $pi_name . '.tab_mobilebotua' => 'Access to configure ' . $pi_name . ' mobile bot user agent'
    );

    $mappings = array(
        $pi_name . '.admin'                       => array($pi_admin),
        'config.' . $pi_name . '.tab_main'        => array($pi_admin),
        'config.' . $pi_name . '.tab_mobilebotua' => array($pi_admin)
    );

    $inst_parms = array(
        'info'      => $info,
        'groups'    => $groups,
        'features'  => $features,
        'mappings'  => $mappings
    );

    return $inst_parms;
}

/**
* Load plugin configuration from database
*
* @param    string  $pi_name    Plugin name
* @return   boolean             true on success, otherwise false
* @see      plugin_initconfig_googleanalytics
*
*/
function plugin_load_configuration_googleanalytics($pi_name)
{
    global $_CONF;

    $base_path = $_CONF['path'] . 'plugins/' . $pi_name . '/';

    require_once $_CONF['path_system'] . 'classes/config.class.php';
    require_once $base_path . 'install_defaults.php';

    return plugin_initconfig_googleanalytics();
}

/**
* Check if the plugin is compatible with this Geeklog version
*
* @param    string  $pi_name    Plugin name
* @return   boolean             true: plugin compatible; false: not compatible
*
*/
function plugin_compatible_with_this_version_googleanalytics($pi_name)
{
    global $_CONF;

    if (! function_exists('SEC_getGroupDropdown')) {
        return false;
    }

    if (! function_exists('SEC_createToken')) {
        return false;
    }

    if (! function_exists('COM_showMessageText')) {
        return false;
    }

    if (! function_exists('COM_setLangIdAndAttribute')) {
        return false;
    }

    if (! isset($_CONF['meta_tags'])) {
        return false;
    }

    if (! function_exists('SEC_getTokenExpiryNotice')) {
        return false;
    }

    if (! function_exists('SEC_loginRequiredForm')) {
        return false;
    }

    return true;
}

?>
