<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | GoogleAnalytics Plugin 1.2
// +---------------------------------------------------------------------------+
// | functions.inc
// |
// | This file provides helper functions for the automatic plugin install. 
// +---------------------------------------------------------------------------+
// | Copyright (C) 2009-2013 by the following authors:
// |
// | Authors: Hiroron               - hiroron AT hiroron DOT com
// +---------------------------------------------------------------------------+
// | 
// | This program is free software; you can redistribute it and/or
// | modify it under the terms of the GNU General Public License
// | as published by the Free Software Foundation; either version 2
// | of the License, or (at your option) any later version.
// | 
// | This program is distributed in the hope that it will be useful,
// | but WITHOUT ANY WARRANTY; without even the implied warranty of
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// | GNU General Public License for more details.
// | 
// | You should have received a copy of the GNU General Public License
// | along with this program; if not, write to the Free Software Foundation,
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// | 
// +---------------------------------------------------------------------------+

/**
* Implementation of the Plugin API for the GoogleAnalytics plugin
*
* @package GoogleAnalytics
*/

if (strpos(strtolower($_SERVER['PHP_SELF']), 'functions.inc') !== false) {
    die('This file can not be used on its own.');
}

/**
* Include language file
*/
$plugin_path = $_CONF['path'] . 'plugins/googleanalytics/';
$langfile = $plugin_path . 'language/' . $_CONF['language'] . '.php';
if (file_exists($langfile)) {
    require_once $langfile;
} else {
    require_once $plugin_path . 'language/japanese_utf-8.php';
}

/*
* Check and see if we need to load the plugin configuration
*/
if (!isset($_GANA_CONF['gatrackingid'])) {
    require_once $_CONF['path_system'] . 'classes/config.class.php';

    $gana_config = config::get_instance();
    $_GANA_CONF = $gana_config->get_config('googleanalytics');
}


// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementation                                         |
// +---------------------------------------------------------------------------+


/**
* Returns the URL of the plugin's icon
*
* @return   string      URL of the icon
*
*/
function plugin_geticon_googleanalytics()
{
    global $_CONF;
    return $_CONF['site_url'] . '/googleanalytics/images/googleanalytics.png';
}


/**
* Return the current version of code.
* Used in the Plugin Editor to show the registered version and code version
*/
function plugin_chkVersion_googleanalytics()
{
    global $_CONF;

    require_once $_CONF['path'] . 'plugins/googleanalytics/autoinstall.php';          

    $inst_parms = plugin_autoinstall_googleanalytics('googleanalytics'); 

    return $inst_parms['info']['pi_version'];
}

/**
* Automatic uninstall function for plugins
*
* @return   array
*
* This code is automatically uninstalling the plugin.
* It passes an array to the core code function that removes
* tables, groups, features and php blocks from the tables.
* Additionally, this code can perform special actions that cannot be
* foreseen by the core code (interactions with other plugins for example)
*
*/
function plugin_autouninstall_googleanalytics ()
{
    $out = array (
        /* give the name of the tables, without $_TABLES[] */
        'tables' => array(),
        /* give the full name of the group, as in the db */
        'groups' => array('GoogleAnalytics Admin'),
        /* give the full name of the feature, as in the db */
        'features' => array('googleanalytics.admin', 
                            'config.googleanalytics.tab_main',
                            'config.googleanalytics.tab_mobilebotua'),
        /* give the full name of the block, including 'phpblock_', etc */
        'php_blocks' => array(),
        /* give all vars with their name */
        'vars'=> array()
    );
    return $out;
}

/**
* Upgrade the googleanalytics plugin
*
* @return   int     Number of message to display (true = generic success msg)
*
*/
function plugin_upgrade_googleanalytics()
{
    global $_CONF, $_TABLES, $_DB_dbms;

    $pi_name = 'googleanalytics';
    $pi_path = $_CONF['path'] . 'plugins/' . $pi_name;
    $installed_version = DB_getItem($_TABLES['plugins'],'pi_version',"pi_name='{$pi_name}'");
    $code_version = plugin_chkVersion_googleanalytics();
    if ($installed_version == $code_version) {
        // nothing to do
        return true;
    }

    require_once $pi_path . '/autoinstall.php';

    if (! plugin_compatible_with_this_version_googleanalytics($pi_name)) {
        return 3002;
    }

    $inst_parms = plugin_autoinstall_googleanalytics($pi_name);
    $pi_gl_version = $inst_parms['info']['pi_gl_version'];

    require_once $pi_path . '/install_updates.php';

    $current_version = $installed_version;
    $done = false;
    $current_config = false;
    // Do upgrading
    while (! $done) {
        switch ($current_version) {
        case '1.0.0':
            googleanalytics_update_ConfValues_1_0_0();
            $current_version = '1.1.0';
            break;

        case '1.1.0':
            googleanalytics_update_ConfValues_1_0_1();
            $current_version = '1.1.1';
            break;

        case '1.1.1':
            // no db changes
            $current_version = '1.1.2';
            break;

        case '1.1.2':
            // no db changes
            break;

        case '1.1.3':
            googleanalytics_update_FeaturesFor_1_1_3();
            $current_version = '1.1.4';
            break;

        case '1.1.4':
            if (isset($_UPDATES[$_DB_dbms][$current_version])) {
                $_SQL = $_UPDATES[$_DB_dbms][$current_version];
                foreach ($_SQL as $sql) {
                    DB_query($sql);
                }
            }
            // Update to Config Tables must be performed here and not in regualar SQL update array since if config is current then they shouldn't be run
            // Set new Tab column to whatever fieldset is
            $sql = "UPDATE {$_TABLES['conf_values']} SET tab = fieldset WHERE group_name = '{$pi_name}'";
            DB_query($sql);                

            googleanalytics_update_FeaturesFor_1_1_4();
            googleanalytics_update_ConfValues_1_1_4();
            googleanalytics_update_ConfigSecurity_1_1_4();
            $current_version = '2.0.0';
            break;

        default:
            $done = true;
        }
    }

    // Update plugin info
    DB_query ("UPDATE {$_TABLES['plugins']} "
            . "SET pi_version = '{$code_version}', pi_gl_version = '{$pi_gl_version}' "
            . "WHERE pi_name = '{$pi_name}'");
    COM_errorLog($pi_name . " plugin was successfully upgraded version {$installed_version} to {$code_version}.");

    return true;
}

/**
* Provide URL of a documentation file
*
* @param    string  $file   documentation file being requested, e.g. 'config'
* @return   mixed           URL or false when not available
*
*/
function plugin_getdocumentationurl_googleanalytics($file)
{
    global $_CONF;

    static $docurl;
    $me = 'googleanalytics';

    switch ($file) {
    case 'index':
    case 'config':
        if (isset($docurl)) {
            $retval = $docurl;
        } else {
            $doclang = COM_getLanguageName();
            $docs = $me . '/docs/' . $me . '_' . $doclang . '.html';
            if (file_exists($_CONF['path_html'] . $docs)) {
                $retval = $_CONF['site_url'] . '/' . $docs;
            } else {
                $retval = $_CONF['site_url'] . '/' . $me . '/docs/' . $me . '.html';
            }
            $docurl = $retval;
        }
        break;

    default:
        $retval = false;
        break;
    }

    return $retval;
}

/**
* Provides text for a Configuration tooltip
*
* @param    string  $id     Id of config value
* @return   mixed           Text to use regular tooltip, NULL to use config 
*                           tooltip hack, or empty string when not available
*
*/
function plugin_getconfigtooltip_googleanalytics($id)
{   
    // Use config tooltip hack where tooltip is read from the config documentation
    return;
}

function plugin_getheadercode_googleanalytics ()
{
    global $_GANA_CONF, $_SCRIPTS;
    
    $code = '';
    if (isset($_GANA_CONF['gatrackingid']) && $_GANA_CONF['gatrackingid'] != 'UA-XXXXXXX-X') {
        $ua_id = $_GANA_CONF['gatrackingid'];
        if (!googleanalytics_is_mobile()) {
            // pc : Asynchronous Tracking
            if (isset($_GANA_CONF['asynchronous']) && $_GANA_CONF['asynchronous']) {
                $code = <<<EOF
<script type="text/javascript">
var _gaq = _gaq || [];
_gaq.push(['_setAccount', '{$ua_id}']);
_gaq.push(['_trackPageview']);
(function() {
var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
})();
</script>
EOF;
                $_SCRIPTS->setJavaScript($code,false,false);
            }
        }
    }
}

function plugin_getfootercode_googleanalytics ()
{
    global $_GANA_CONF, $_SCRIPTS;

    $ret = '';
    $code = '';
    if (isset($_GANA_CONF['gatrackingid']) && $_GANA_CONF['gatrackingid'] != 'UA-XXXXXXX-X') {
        $ua_id = $_GANA_CONF['gatrackingid'];
        if (googleanalytics_is_mobile()) {
            // mobile
            if (!empty($_GANA_CONF['gatrackingid_mobile']) && $_GANA_CONF['gatrackingid_mobile'] != 'UA-XXXXXXX-X' ) {
                $ua_id = $_GANA_CONF['gatrackingid_mobile'];
            }
            if ( !googleanalytics_isbot_mobile() ) {    // bot check
                $ret  = '<!-- mobile GAnalytics .' . $ua_id;
                $ret .= ' sendReqCode(' . googleanalytics_mobile_code_sending($ua_id) . ')';
                $ret .= ' -->';
            }

        } else {
            // pc : Synchronous Tracking
            if (! isset($_GANA_CONF['asynchronous']) || ! $_GANA_CONF['asynchronous']) {
                $code = <<<EOF
<script type="text/javascript">
var gaJsHost = (("https:" == document.location.protocol) ? "https://ssl." : "http://www.");
document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
</script>
<script type="text/javascript">
try {
var pageTracker = _gat._getTracker("{$ua_id}");
pageTracker._trackPageview();
} catch(err) {}</script>
EOF;
                $_SCRIPTS->setJavaScript($code,false,true);
            }
        }
    }
    return $ret;
}

function googleanalytics_mobile_code_sending ($id)
{
    global $_CONF;

    require_once 'HTTP/Request.php';

    $var_utmac   = $id;
    $var_utmhn   = str_replace('https://', '', $_CONF['site_url']);
    $var_utmhn   = str_replace('http://', '', $var_utmhn);    
    $var_utmn    = rand(1000000000,9999999999);
    $var_cookie  = '';
    $var_today   = time();
    $var_referer = $_SERVER['HTTP_REFERER'];
    $var_uservar = '';
    $var_utmp    = $_SERVER['REQUEST_URI'];
    
    $g_url = 'http://www.google-analytics.com/__utm.gif?utmwv=1&utmn='.$var_utmn.'&utmsr=-&utmsc=-&utmul=-&utmje=0&utmfl=-&utmdt=-&utmhn='.$var_utmhn.'&utmr='.$var_referer.'&utmp='.$var_utmp.'&utmac='.$var_utmac.'&utmcc=__utma%3D'.$var_cookie.'.'.$var_random.'.'.$var_today.'.'.$var_today.'.'.$var_today.'.2%3B%2B__utmb%3D'.$var_cookie.'%3B%2B__utmc%3D'.$var_cookie.'%3B%2B__utmz%3D'.$var_cookie.'.'.$var_today.'.2.2.utmccn%3D(direct)%7Cutmcsr%3D(direct)%7Cutmcmd%3D(none)%3B%2B__utmv%3D'.$var_cookie.'.'.$var_uservar.'%3B';
    
    $header = array();
    //Set the language to that of the client so analytics can track it.
    if (!empty($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
        $header['Accept-language'] = $_SERVER['HTTP_ACCEPT_LANGUAGE'].'\r\n';
    }
    //Set the user agent to that of the client so analytics can track it.
    if (!empty($_SERVER['HTTP_USER_AGENT'])) {
        $header['User-Agent'] = $_SERVER['HTTP_USER_AGENT'].'\r\n';
    }
    
    $req = new HTTP_Request($g_url);
    //$req->setMethod(HTTP_REQUEST_METHOD_HEAD);
    if (count($header) > 0) {
        foreach ( $header as $key => $val ) {
            $req->addHeader($key, $val);
        }
    }
    $response = $req->sendRequest ();
    if (PEAR::isError ($response)) {
        $msg = $response->getMessage();
        COM_errorLog('GANA: mobile code sending error! - ' . $msg);
        return 999;
    } else {
        // all status coce http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html
        return $req->getResponseCode();
    }
}

function googleanalytics_isbot_mobile ()
{
    global $_GANA_CONF;
    
    if (! isset($_GANA_CONF['nomobilebottracking']) || ! $_GANA_CONF['nomobilebottracking']) {
        return false;
    }
    
    $bots = array(
        'Googlebot-Mobile',
        'BaiduMobaider',
        'Y!J-SRD',
        'Y!J-MRD',
        'moba-crawler',
        'mobile goo',
        'LD_mobile_bot',
        'froute.jp'
    );
    if ( isset($_GANA_CONF['mobilebotua']) && $_GANA_CONF['mobilebotua'] ) {
        $bots = $_GANA_CONF['mobilebotua'];
    }
    
    foreach ($bots as $bot) {
        if (!empty($_SERVER['HTTP_USER_AGENT']) && strpos($_SERVER['HTTP_USER_AGENT'], $bot) !== false) {
            return true;
        }
    }
    return false;
}

function googleanalytics_is_mobile ()
{
    if (function_exists('CUSTOM_MOBILE_is_cellular')) {
        return (CUSTOM_MOBILE_is_cellular()) ? TRUE : FALSE;;
    } else {
        return FALSE;
    }
}

?>